pub enum Cmd<P> {
Broadcast {
id: BroadcastId,
msg: P,
},
Stop {
id: BroadcastId,
},
}Expand description
Requests from the layer above.
Variants
Broadcast
Broadcast msg as id, and keep transmitting it until stopped.
Stop
Stop retransmitting the broadcast named id, on every link it went out over.
Fields

id: BroadcastIdTrait Implementations
impl<P: Eq> Eq for Cmd<P>
impl<P: PartialEq> StructuralPartialEq for Cmd<P>